/// displays a short celebratory line
void hip();

/// displays a celebratory line consisting of `rep` repetitions of some word or phrase.
void hooray(int rep);

/// displays a line representing an accepting nonverbal noise.
void accept();

/// displays a line representing a rejecting nonverbal noise.
void reject();

/// displays a line representing an emphatic rejection including `rep` repetitions of some word or phrase.
void weep(int rep);
